s390: revert ELF_ET_DYN_BASE base changes

commit 345f8f34bb upstream.

This reverts commit a73dc5370e.

Reducing the base address for 31-bit PIE executables from
(STACK_TOP/3)*2 to 4MB broke several compat programs which
use -fpie to move the executable out of the lower 16MB.

Signed-off-by: Martin Schwidefsky <schwidefsky@de.ibm.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
This commit is contained in:
Martin Schwidefsky 2017-11-24 16:23:15 +01:00 • committed by Greg Kroah-Hartman
commit b367ea9453